#
# spec file for package kf6-kjobwidgets
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kjobwidgets
# Full KF6 version (e.g. 6.13.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kjobwidgets
Version:        6.13.0
Release:        1.1
Summary:        Widgets for showing progress of asynchronous jobs
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Notifications) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(x11)

%description
KJobWIdgets provides widgets for showing progress of asynchronous jobs.

%package -n libKF6JobWidgets6
Summary:        Widgets for showing progress of asynchronous jobs
Requires:       kf6-kjobwidgets >= %{version}

%description -n libKF6JobWidgets6
KJobWIdgets provides widgets for showing progress of asynchronous jobs.

%package devel
Summary:        Widgets for showing progress of asynchronous jobs
Requires:       libKF6JobWidgets6 = %{version}
Requires:       cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
Requires:       cmake(Qt6Widgets) >= %{qt6_version}

%description devel
KJobWIdgets provides widgets for showing progress of asynchronous jobs.
Development files.

%lang_package -n libKF6JobWidgets6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kjobwidgets6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6JobWidgets6

%files
%{_kf6_debugdir}/kjobwidgets.categories
%{_kf6_debugdir}/kjobwidgets.renamecategories

%files -n libKF6JobWidgets6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6JobWidgets.so.*

%files devel
%doc %{_kf6_qchdir}/KF6JobWidgets.*
%{_kf6_cmakedir}/KF6JobWidgets/
%{_kf6_dbusinterfacesdir}/kf6_org.kde.JobView.xml
%{_kf6_dbusinterfacesdir}/kf6_org.kde.JobViewServer.xml
%{_kf6_dbusinterfacesdir}/kf6_org.kde.JobViewV2.xml
%{_kf6_includedir}/KJobWidgets/
%{_kf6_libdir}/libKF6JobWidgets.so

%files -n libKF6JobWidgets6-lang -f kjobwidgets6.lang

%changelog
* Sat Apr  5 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.13.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.13.0
- Changes since 6.12.0:
  * It compiles fine without qt6.9 deprecated methods
  * It compiles fine without kf6.12 deprecated methods
  * kjobcreator: startElapsedTimer in Testjob::start
  * Update dependency version to 6.13.0
* Tue Mar 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.12.0
- Changes since 6.11.0:
  * Update dependency version to 6.12.0
  * Update version to 6.12.0
* Sat Feb  8 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.11.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.11.0
- Changes since 6.10.0:
  * Update dependency version to 6.11.0
  * Fix build with Qt 6.10
  * Add xml/yaml linting
  * CI: Add linux-qt6-next build
  * Update version to 6.11.0
* Thu Jan  9 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.10.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.10.0
- Changes since 6.9.0:
  * Update dependency version to 6.10.0
  * Update version to 6.10.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * Add a first basic autotest
  * JobView: expose elapsedTime
  * Disable X11 on Haiku also
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Hide arrowButton in KWidgetJobTracker on startup
  * Add dedicated WITH_X11 option to avoid automagic
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * Only install D-Bus interface files when actually building with D-Bus
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * support USE_DBUS option to enable/disable dbus use
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * KUiServerV2JobTracker: prevent a crash (kde#471531)
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * tests need dbus due to KUiServerJobTracker
  * kjobtrackerstest needs dbus
  * TARGET Qt6::DBus doesn't work if dependencies export it
  * Don't search for QtDBus on Windows/macOS/Android
  * Simplify X11 check
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kjobwidgets
